import 'package:flutter/material.dart';
import 'package:kvalifika_sdk/kvalifika_sdk.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  bool isGeorgian = false;
  bool isSdkInitialize = false;

  KvalifikaSdkLocale get locale {
    if (isGeorgian) return KvalifikaSdkLocale.GE;
    return KvalifikaSdkLocale.EN;
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Kvalifika'),
          // actions: [
          //   Switch(
          //     value: isGeorgian,
          //     onChanged: (val) {
          //       setState(() {
          //         isGeorgian = val;
          //       });
          //     },
          //   ),
          // ],
        ),
        body: KvalifikaSdk(
          // appId: "7bd2bab9-5bcb-4f8d-a0c8-d7fd3fd4653b", // Production21caf4ed-4240-4ef3-bba0-04257bedc835
          // appId: "d4bb88d7-8e6d-4653-baef-9d87c1e102e6", // Development
          appId: "21caf4ed-4240-4ef3-bba0-04257bedc835",
          // from -android sdk
          development: true,
          locale: locale,
          logo: "logo",
          documentIcon: "logo",
          onInitialize: (context, sdk) {
            setState(() {
              isSdkInitialize = true;
            });
            ScaffoldMessenger.of(context).showSnackBar(
              SnackBar(
                content: Text('SDK Initialized'),
              ),
            );
            sdk.startSession();
          },
          onStart: (context, sessionId) {
            setState(() {
              isSdkInitialize = true;
              // counter++;
            });
            ScaffoldMessenger.of(context).showSnackBar(
              SnackBar(
                content: Text('Started Verification'),
              ),
            );
          },
          onFinish: (context, sessionId) {},
          onError: (context, error, message) {
            print(error);

            if (error == KvalifikaSdkError.TIMEOUT) {
              ScaffoldMessenger.of(context).showSnackBar(
                SnackBar(
                  content: Text('Timeout'),
                ),
              );
            }

            if (error == KvalifikaSdkError.USER_CANCELLED) {
              ScaffoldMessenger.of(context).showSnackBar(
                SnackBar(
                  content: Text('User Canceled'),
                ),
              );
            }
          },
          builder: (BuildContext context, KvalifikaSdk sdk) {
            return Center(
              child: Container(
                margin: EdgeInsets.only(bottom: 40),
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    isSdkInitialize
                        ? SizedBox(
                            height: 120,
                            width: 120,
                          )
                        : SizedBox(
                            height: 120,
                            width: 120,
                            child: CircularProgressIndicator(),
                          ),
                    Container(
                      margin: EdgeInsets.only(top: 20),
                      child: ElevatedButton(
                        key: const Key('start_session'),
                        onPressed: () {
                          if(isSdkInitialize) {
                            sdk.startSession();
                          }
                        },
                        child: Text('Start Verification'),
                      ),
                    ),
                  ],
                ),
              ),
            );
          },
        ),
      ),
    );
  }
}
